@@ -28,19 +28,19 @@
 #include <cmath>
 #include <cstdlib>
 
-// Qt includes.
+// Qt includes
 
 #include <Q3ValueList>
-#include <qtimer.h>
-#include <qpixmap.h>
-#include <qapplication.h>
-#include <qevent.h>
-#include <qcursor.h>
-#include <qimage.h>
-#include <qpainter.h>
-#include <qfileinfo.h>
-#include <qfontmetrics.h>
-#include <qmatrix.h>
+#include <QTimer>
+#include <QPixmap>
+#include <QApplication>
+#include <QEvent>
+#include <QCursor>
+#include <QImage>
+#include <QPainter>
+#include <QFileInfo>
+#include <QFontMetrics>
+#include <QMatrix>
 #include <QKeyEvent>
 #include <QMouseEvent>
 #include <QWheelEvent>
@@ -48,7 +48,7 @@
 #include <QSvgRenderer>
 #include <QPainter>
 
-// KDE includes.
+// KDE includes
 
 #include <kconfig.h>
 #include <klocale.h>
@@ -734,8 +734,8 @@ void SlideShowGL::showEndOfShow()
     QPainter p(&pix);
     p.setPen(Qt::white);
     p.setFont(fn);
-    p.drawText(20, 50, i18n("Slideshow Completed."));
-    p.drawText(20, 100, i18n("Click To Exit..."));
+    p.drawText(20, 50, i18n("Slideshow Completed"));
+    p.drawText(20, 100, i18n("Click to Exit..."));
 
     QSvgRenderer svgRenderer( KStandardDirs::locate("data", "kipiplugin_advancedslideshow/KIPIicon.svg") );
     QPixmap kipiLogoPixmap = QPixmap(width()/6, width()/6);
