@@ -60,7 +60,7 @@
 
 // Local includes
 
-#include "dngwriterprivate.h"
+#include "dngwriter_p.h"
 #include "dngwriterhost.h"
 #include "dngwriter.h"
 
@@ -147,7 +147,7 @@ int DNGWriter::convert()
     {
         if (inputFile().isEmpty())
         {
-            kDebug( 51000 ) << "DNGWriter: No input file to convert. Aborted..." << endl;
+            kDebug(51000) << "DNGWriter: No input file to convert. Aborted..." << endl;
             return -1;
         }
 
@@ -156,7 +156,7 @@ int DNGWriter::convert()
 
         if (dngFilePath.isEmpty())
         {
-            dngFilePath = QString(inputInfo.baseName() + QString(".dng"));
+            dngFilePath = QString(inputInfo.completeBaseName() + QString(".dng"));
         }
 
         QFileInfo          outputInfo(dngFilePath);
@@ -165,12 +165,12 @@ int DNGWriter::convert()
 
         // -----------------------------------------------------------------------------------------
 
-        kDebug( 51000 ) << "DNGWriter: Loading RAW data from " << inputInfo.fileName() << endl;
+        kDebug(51000) << "DNGWriter: Loading RAW data from " << inputInfo.fileName() << endl;
 
         KDcraw rawProcessor;
         if (!rawProcessor.extractRAWData(inputFile(), rawData, identify))
         {
-            kDebug( 51000 ) << "DNGWriter: Loading RAW data failed. Aborted..." << endl;
+            kDebug(51000) << "DNGWriter: Loading RAW data failed. Aborted..." << endl;
             return -1;
         }
 
@@ -180,29 +180,29 @@ int DNGWriter::convert()
         int height     = identify.imageSize.height();
         int pixelRange = 16;
 
-        kDebug( 51000 ) << "DNGWriter: Raw data loaded:" << endl;
-        kDebug( 51000 ) << "--- Data Size:     " << rawData.size() << " bytes" << endl;
-        kDebug( 51000 ) << "--- Date:          " << identify.dateTime.toString(Qt::ISODate) << endl;
-        kDebug( 51000 ) << "--- Make:          " << identify.make << endl;
-        kDebug( 51000 ) << "--- Model:         " << identify.model << endl;
-        kDebug( 51000 ) << "--- Size:          " << width << "x" << height << endl;
-        kDebug( 51000 ) << "--- Orientation:   " << identify.orientation << endl;
-        kDebug( 51000 ) << "--- Top margin:    " << identify.topMargin << endl;
-        kDebug( 51000 ) << "--- Left margin:   " << identify.leftMargin << endl;
-        kDebug( 51000 ) << "--- Filter:        " << identify.filterPattern << endl;
-        kDebug( 51000 ) << "--- Colors:        " << identify.rawColors << endl;
-        kDebug( 51000 ) << "--- Black:         " << identify.blackPoint << endl;
-        kDebug( 51000 ) << "--- White:         " << identify.whitePoint << endl;
-        kDebug( 51000 ) << "--- CAM->XYZ:" << endl;
+        kDebug(51000) << "DNGWriter: Raw data loaded:" << endl;
+        kDebug(51000) << "--- Data Size:     " << rawData.size() << " bytes" << endl;
+        kDebug(51000) << "--- Date:          " << identify.dateTime.toString(Qt::ISODate) << endl;
+        kDebug(51000) << "--- Make:          " << identify.make << endl;
+        kDebug(51000) << "--- Model:         " << identify.model << endl;
+        kDebug(51000) << "--- Size:          " << width << "x" << height << endl;
+        kDebug(51000) << "--- Orientation:   " << identify.orientation << endl;
+        kDebug(51000) << "--- Top margin:    " << identify.topMargin << endl;
+        kDebug(51000) << "--- Left margin:   " << identify.leftMargin << endl;
+        kDebug(51000) << "--- Filter:        " << identify.filterPattern << endl;
+        kDebug(51000) << "--- Colors:        " << identify.rawColors << endl;
+        kDebug(51000) << "--- Black:         " << identify.blackPoint << endl;
+        kDebug(51000) << "--- White:         " << identify.whitePoint << endl;
+        kDebug(51000) << "--- CAM->XYZ:" << endl;
 
         QString matrixVal;
         for(int i=0; i<12; i+=3)
         {
-            kDebug( 51000 ) << "                   "
-                     << QString().sprintf("%03.4f  %03.4f  %03.4f", identify.cameraXYZMatrix[0][ i ],
-                                                                    identify.cameraXYZMatrix[0][i+1],
-                                                                    identify.cameraXYZMatrix[0][i+2])
-                     << endl;
+            kDebug(51000) << "                   "
+                          << QString().sprintf("%03.4f  %03.4f  %03.4f", identify.cameraXYZMatrix[0][ i ],
+                                                                         identify.cameraXYZMatrix[0][i+1],
+                                                                         identify.cameraXYZMatrix[0][i+2])
+                          << endl;
         }
 
         // Check if CFA layout is supported by DNG SDK.
@@ -226,14 +226,14 @@ int DNGWriter::convert()
         }
         else
         {
-            kDebug( 51000 ) << "DNGWriter: Bayer mosaic not supported. Aborted..." << endl;
+            kDebug(51000) << "DNGWriter: Bayer mosaic not supported. Aborted..." << endl;
             return -1;
         }
 
         // Check if number of Raw Color components is supported.
         if (identify.rawColors != 3)
         {
-            kDebug( 51000 ) << "DNGWriter: Number of Raw color components not supported. Aborted..." << endl;
+            kDebug(51000) << "DNGWriter: Number of Raw color components not supported. Aborted..." << endl;
             return -1;
         }
 
@@ -245,7 +245,7 @@ int DNGWriter::convert()
         QFile rawdataFile(rawdataFilePath);
         if (!rawdataFile.open(QIODevice::WriteOnly))
         {
-            kDebug( 51000 ) << "DNGWriter: Cannot open file to write RAW data. Aborted..." << endl;
+            kDebug(51000) << "DNGWriter: Cannot open file to write RAW data. Aborted..." << endl;
             return -1;
         }
         QDataStream rawdataStream(&rawdataFile);
@@ -254,7 +254,7 @@ int DNGWriter::convert()
 */
         // -----------------------------------------------------------------------------------------
 
-        kDebug( 51000 ) << "DNGWriter: Formating RAW data to memory" << endl;
+        kDebug(51000) << "DNGWriter: Formating RAW data to memory" << endl;
 
         std::vector<unsigned short> raw_data;
         raw_data.resize(rawData.size());
@@ -269,7 +269,7 @@ int DNGWriter::convert()
 
         // -----------------------------------------------------------------------------------------
 
-        kDebug( 51000 ) << "DNGWriter: DNG memory allocation and initialization" << endl;
+        kDebug(51000) << "DNGWriter: DNG memory allocation and initialization" << endl;
 
         dng_memory_allocator memalloc(gDefaultDNGMemoryAllocator);
         dng_memory_stream stream(memalloc);
@@ -290,7 +290,7 @@ int DNGWriter::convert()
 
         // -----------------------------------------------------------------------------------------
 
-        kDebug( 51000 ) << "DNGWriter: DNG IFD structure creation" << endl;
+        kDebug(51000) << "DNGWriter: DNG IFD structure creation" << endl;
 
         dng_ifd ifd;
 
@@ -375,7 +375,7 @@ int DNGWriter::convert()
 
         // -----------------------------------------------------------------------------------------
 
-        kDebug( 51000 ) << "DNGWriter: DNG Negative structure creation" << endl;
+        kDebug(51000) << "DNGWriter: DNG Negative structure creation" << endl;
 
         AutoPtr<dng_negative> negative(host.Make_dng_negative());
 
@@ -450,8 +450,8 @@ int DNGWriter::convert()
         camXYZ[2][2] = identify.cameraXYZMatrix[2][0];
 
         if (camXYZ.MaxEntry() == 0.0)
-            kDebug( 51000 ) << "DNGWriter: Warning, camera XYZ Matrix is null" << endl;
-        else 
+            kDebug(51000) << "DNGWriter: Warning, camera XYZ Matrix is null" << endl;
+        else
             matrix = camXYZ;
 
         prof->SetColorMatrix1((dng_matrix) matrix);
@@ -470,7 +470,7 @@ int DNGWriter::convert()
 
         // -----------------------------------------------------------------------------------------
 
-        kDebug( 51000 ) << "DNGWriter: Updating metadata to DNG Negative" << endl;
+        kDebug(51000) << "DNGWriter: Updating metadata to DNG Negative" << endl;
 
         dng_exif *exif = negative->GetExif();
         exif->fModel.Set_ASCII(identify.model.toAscii());
@@ -570,65 +570,65 @@ int DNGWriter::convert()
 
             // Rational Tags
 
-            if (meta.getExifTagRational("Exif.Photo.ExposureTime", num, den))          exif->fExposureTime          = dng_urational(num, den);
-            if (meta.getExifTagRational("Exif.Photo.FNumber", num, den))               exif->fFNumber               = dng_urational(num, den);
-            if (meta.getExifTagRational("Exif.Photo.ShutterSpeedValue", num, den))     exif->fShutterSpeedValue     = dng_srational(num, den);
-            if (meta.getExifTagRational("Exif.Photo.ApertureValue", num, den))         exif->fApertureValue         = dng_urational(num, den);
-            if (meta.getExifTagRational("Exif.Photo.BrightnessValue", num, den))       exif->fBrightnessValue       = dng_srational(num, den);
-            if (meta.getExifTagRational("Exif.Photo.ExposureBiasValue", num, den))     exif->fExposureBiasValue     = dng_srational(num, den);
-            if (meta.getExifTagRational("Exif.Photo.MaxApertureValue", num, den))      exif->fMaxApertureValue      = dng_urational(num, den);
-            if (meta.getExifTagRational("Exif.Photo.FocalLength", num, den))           exif->fFocalLength           = dng_urational(num, den);
-            if (meta.getExifTagRational("Exif.Photo.DigitalZoomRatio", num, den))      exif->fDigitalZoomRatio      = dng_urational(num, den);
-            if (meta.getExifTagRational("Exif.Photo.SubjectDistance", num, den))       exif->fSubjectDistance       = dng_urational(num, den);
-            if (meta.getExifTagRational("Exif.Image.BatteryLevel", num, den))          exif->fBatteryLevelR         = dng_urational(num, den);
-            if (meta.getExifTagRational("Exif.Photo.FocalPlaneXResolution", num, den)) exif->fFocalPlaneXResolution = dng_urational(num, den);
-            if (meta.getExifTagRational("Exif.Photo.FocalPlaneYResolution", num, den)) exif->fFocalPlaneYResolution = dng_urational(num, den);
-            if (meta.getExifTagRational("Exif.GPSInfo.GPSAltitude", num, den))         exif->fGPSAltitude           = dng_urational(num, den);
-            if (meta.getExifTagRational("Exif.GPSInfo.GPSDOP", num, den))              exif->fGPSDOP                = dng_urational(num, den);
-            if (meta.getExifTagRational("Exif.GPSInfo.GPSSpeed", num, den))            exif->fGPSSpeed              = dng_urational(num, den);
-            if (meta.getExifTagRational("Exif.GPSInfo.GPSTrack", num, den))            exif->fGPSTrack              = dng_urational(num, den);
-            if (meta.getExifTagRational("Exif.GPSInfo.GPSImgDirection", num, den))     exif->fGPSImgDirection       = dng_urational(num, den);
-            if (meta.getExifTagRational("Exif.GPSInfo.GPSDestBearing", num, den))      exif->fGPSDestBearing        = dng_urational(num, den);
-            if (meta.getExifTagRational("Exif.GPSInfo.GPSDestDistance", num, den))     exif->fGPSDestDistance       = dng_urational(num, den);
-            if (meta.getExifTagRational("Exif.GPSInfo.GPSLatitude", num, den))         exif->fGPSLatitude[0]        = dng_urational(num, den);
-            if (meta.getExifTagRational("Exif.GPSInfo.GPSLongitude", num, den))        exif->fGPSLongitude[0]       = dng_urational(num, den);
-            if (meta.getExifTagRational("Exif.GPSInfo.GPSTimeStamp", num, den))        exif->fGPSTimeStamp[0]       = dng_urational(num, den);
-            if (meta.getExifTagRational("Exif.GPSInfo.GPSDestLatitude", num, den))     exif->fGPSDestLatitude[0]    = dng_urational(num, den);
-            if (meta.getExifTagRational("Exif.GPSInfo.GPSDestLongitude", num, den))    exif->fGPSDestLongitude[0]   = dng_urational(num, den);
+            if (meta.getExifTagRational("Exif.Photo.ExposureTime", num, den))          exif->fExposureTime             = dng_urational(num, den);
+            if (meta.getExifTagRational("Exif.Photo.FNumber", num, den))               exif->fFNumber                  = dng_urational(num, den);
+            if (meta.getExifTagRational("Exif.Photo.ShutterSpeedValue", num, den))     exif->fShutterSpeedValue        = dng_srational(num, den);
+            if (meta.getExifTagRational("Exif.Photo.ApertureValue", num, den))         exif->fApertureValue            = dng_urational(num, den);
+            if (meta.getExifTagRational("Exif.Photo.BrightnessValue", num, den))       exif->fBrightnessValue          = dng_srational(num, den);
+            if (meta.getExifTagRational("Exif.Photo.ExposureBiasValue", num, den))     exif->fExposureBiasValue        = dng_srational(num, den);
+            if (meta.getExifTagRational("Exif.Photo.MaxApertureValue", num, den))      exif->fMaxApertureValue         = dng_urational(num, den);
+            if (meta.getExifTagRational("Exif.Photo.FocalLength", num, den))           exif->fFocalLength              = dng_urational(num, den);
+            if (meta.getExifTagRational("Exif.Photo.DigitalZoomRatio", num, den))      exif->fDigitalZoomRatio         = dng_urational(num, den);
+            if (meta.getExifTagRational("Exif.Photo.SubjectDistance", num, den))       exif->fSubjectDistance          = dng_urational(num, den);
+            if (meta.getExifTagRational("Exif.Image.BatteryLevel", num, den))          exif->fBatteryLevelR            = dng_urational(num, den);
+            if (meta.getExifTagRational("Exif.Photo.FocalPlaneXResolution", num, den)) exif->fFocalPlaneXResolution    = dng_urational(num, den);
+            if (meta.getExifTagRational("Exif.Photo.FocalPlaneYResolution", num, den)) exif->fFocalPlaneYResolution    = dng_urational(num, den);
+            if (meta.getExifTagRational("Exif.GPSInfo.GPSAltitude", num, den))         exif->fGPSAltitude              = dng_urational(num, den);
+            if (meta.getExifTagRational("Exif.GPSInfo.GPSDOP", num, den))              exif->fGPSDOP                   = dng_urational(num, den);
+            if (meta.getExifTagRational("Exif.GPSInfo.GPSSpeed", num, den))            exif->fGPSSpeed                 = dng_urational(num, den);
+            if (meta.getExifTagRational("Exif.GPSInfo.GPSTrack", num, den))            exif->fGPSTrack                 = dng_urational(num, den);
+            if (meta.getExifTagRational("Exif.GPSInfo.GPSImgDirection", num, den))     exif->fGPSImgDirection          = dng_urational(num, den);
+            if (meta.getExifTagRational("Exif.GPSInfo.GPSDestBearing", num, den))      exif->fGPSDestBearing           = dng_urational(num, den);
+            if (meta.getExifTagRational("Exif.GPSInfo.GPSDestDistance", num, den))     exif->fGPSDestDistance          = dng_urational(num, den);
+            if (meta.getExifTagRational("Exif.GPSInfo.GPSLatitude", num, den))         exif->fGPSLatitude[0]           = dng_urational(num, den);
+            if (meta.getExifTagRational("Exif.GPSInfo.GPSLongitude", num, den))        exif->fGPSLongitude[0]          = dng_urational(num, den);
+            if (meta.getExifTagRational("Exif.GPSInfo.GPSTimeStamp", num, den))        exif->fGPSTimeStamp[0]          = dng_urational(num, den);
+            if (meta.getExifTagRational("Exif.GPSInfo.GPSDestLatitude", num, den))     exif->fGPSDestLatitude[0]       = dng_urational(num, den);
+            if (meta.getExifTagRational("Exif.GPSInfo.GPSDestLongitude", num, den))    exif->fGPSDestLongitude[0]      = dng_urational(num, den);
 
             // Integer Tags
 
-            if (meta.getExifTagLong("Exif.Photo.ExposureProgram", val))          exif->fExposureProgram          = (uint32)val;
-            if (meta.getExifTagLong("Exif.Photo.MeteringMode", val))             exif->fMeteringMode             = (uint32)val;
-            if (meta.getExifTagLong("Exif.Photo.LightSource", val))              exif->fLightSource              = (uint32)val;
-            if (meta.getExifTagLong("Exif.Photo.Flash", val))                    exif->fFlash                    = (uint32)val;
-            if (meta.getExifTagLong("Exif.Photo.SensingMethod", val))            exif->fSensingMethod            = (uint32)val;
-            if (meta.getExifTagLong("Exif.Photo.FileSource", val))               exif->fFileSource               = (uint32)val;
-            if (meta.getExifTagLong("Exif.Photo.SceneType", val))                exif->fSceneType                = (uint32)val;
-            if (meta.getExifTagLong("Exif.Photo.CustomRendered", val))           exif->fCustomRendered           = (uint32)val;
-            if (meta.getExifTagLong("Exif.Photo.ExposureMode", val))             exif->fExposureMode             = (uint32)val;
-            if (meta.getExifTagLong("Exif.Photo.WhiteBalance", val))             exif->fWhiteBalance             = (uint32)val;
-            if (meta.getExifTagLong("Exif.Photo.SceneCaptureType", val))         exif->fSceneCaptureType         = (uint32)val;
-            if (meta.getExifTagLong("Exif.Photo.GainControl", val))              exif->fGainControl              = (uint32)val;
-            if (meta.getExifTagLong("Exif.Photo.Contrast", val))                 exif->fContrast                 = (uint32)val;
-            if (meta.getExifTagLong("Exif.Photo.Saturation", val))               exif->fSaturation               = (uint32)val;
-            if (meta.getExifTagLong("Exif.Photo.Sharpness", val))                exif->fSharpness                = (uint32)val;
-            if (meta.getExifTagLong("Exif.Photo.SubjectDistanceRange", val))     exif->fSubjectDistanceRange     = (uint32)val;
-            if (meta.getExifTagLong("Exif.Photo.FocalLengthIn35mmFilm", val))    exif->fFocalLengthIn35mmFilm    = (uint32)val;
-            if (meta.getExifTagLong("Exif.Photo.ComponentsConfiguration", val))  exif->fComponentsConfiguration  = (uint32)val;
-            if (meta.getExifTagLong("Exif.Photo.PixelXDimension", val))          exif->fPixelXDimension          = (uint32)val;
-            if (meta.getExifTagLong("Exif.Photo.PixelYDimension", val))          exif->fPixelYDimension          = (uint32)val;
-            if (meta.getExifTagLong("Exif.Photo.FocalPlaneResolutionUnit", val)) exif->fFocalPlaneResolutionUnit = (uint32)val;
-            if (meta.getExifTagLong("Exif.GPSInfo.GPSVersionID", val))           exif->fGPSVersionID             = (uint32)val;
-            if (meta.getExifTagLong("Exif.GPSInfo.GPSAltitudeRef", val))         exif->fGPSAltitudeRef           = (uint32)val;
-            if (meta.getExifTagLong("Exif.GPSInfo.GPSDifferential", val))        exif->fGPSDifferential          = (uint32)val;
+            if (meta.getExifTagLong("Exif.Photo.ExposureProgram", val))                exif->fExposureProgram          = (uint32)val;
+            if (meta.getExifTagLong("Exif.Photo.MeteringMode", val))                   exif->fMeteringMode             = (uint32)val;
+            if (meta.getExifTagLong("Exif.Photo.LightSource", val))                    exif->fLightSource              = (uint32)val;
+            if (meta.getExifTagLong("Exif.Photo.Flash", val))                          exif->fFlash                    = (uint32)val;
+            if (meta.getExifTagLong("Exif.Photo.SensingMethod", val))                  exif->fSensingMethod            = (uint32)val;
+            if (meta.getExifTagLong("Exif.Photo.FileSource", val))                     exif->fFileSource               = (uint32)val;
+            if (meta.getExifTagLong("Exif.Photo.SceneType", val))                      exif->fSceneType                = (uint32)val;
+            if (meta.getExifTagLong("Exif.Photo.CustomRendered", val))                 exif->fCustomRendered           = (uint32)val;
+            if (meta.getExifTagLong("Exif.Photo.ExposureMode", val))                   exif->fExposureMode             = (uint32)val;
+            if (meta.getExifTagLong("Exif.Photo.WhiteBalance", val))                   exif->fWhiteBalance             = (uint32)val;
+            if (meta.getExifTagLong("Exif.Photo.SceneCaptureType", val))               exif->fSceneCaptureType         = (uint32)val;
+            if (meta.getExifTagLong("Exif.Photo.GainControl", val))                    exif->fGainControl              = (uint32)val;
+            if (meta.getExifTagLong("Exif.Photo.Contrast", val))                       exif->fContrast                 = (uint32)val;
+            if (meta.getExifTagLong("Exif.Photo.Saturation", val))                     exif->fSaturation               = (uint32)val;
+            if (meta.getExifTagLong("Exif.Photo.Sharpness", val))                      exif->fSharpness                = (uint32)val;
+            if (meta.getExifTagLong("Exif.Photo.SubjectDistanceRange", val))           exif->fSubjectDistanceRange     = (uint32)val;
+            if (meta.getExifTagLong("Exif.Photo.FocalLengthIn35mmFilm", val))          exif->fFocalLengthIn35mmFilm    = (uint32)val;
+            if (meta.getExifTagLong("Exif.Photo.ComponentsConfiguration", val))        exif->fComponentsConfiguration  = (uint32)val;
+            if (meta.getExifTagLong("Exif.Photo.PixelXDimension", val))                exif->fPixelXDimension          = (uint32)val;
+            if (meta.getExifTagLong("Exif.Photo.PixelYDimension", val))                exif->fPixelYDimension          = (uint32)val;
+            if (meta.getExifTagLong("Exif.Photo.FocalPlaneResolutionUnit", val))       exif->fFocalPlaneResolutionUnit = (uint32)val;
+            if (meta.getExifTagLong("Exif.GPSInfo.GPSVersionID", val))                 exif->fGPSVersionID             = (uint32)val;
+            if (meta.getExifTagLong("Exif.GPSInfo.GPSAltitudeRef", val))               exif->fGPSAltitudeRef           = (uint32)val;
+            if (meta.getExifTagLong("Exif.GPSInfo.GPSDifferential", val))              exif->fGPSDifferential          = (uint32)val;
 
             // Markernote backup.
 
             QByteArray mkrnts = meta.getExifTagData("Exif.Photo.MakerNote");
             if (!mkrnts.isEmpty())
             {
-                kDebug( 51000 ) << "DNGWriter: Backup Makernote (" << mkrnts.size() << " bytes)" << endl;
+                kDebug(51000) << "DNGWriter: Backup Makernote (" << mkrnts.size() << " bytes)" << endl;
 
                 dng_memory_allocator memalloc(gDefaultDNGMemoryAllocator);
                 dng_memory_stream stream(memalloc);
@@ -643,14 +643,14 @@ int DNGWriter::convert()
 
         if (d->backupOriginalRawFile)
         {
-            kDebug( 51000 ) << "DNGWriter: Backup Original RAW file (" << inputInfo.size() << " bytes)" << endl;
+            kDebug(51000) << "DNGWriter: Backup Original RAW file (" << inputInfo.size() << " bytes)" << endl;
 
             // Compress Raw file data to Zip archive.
 
             QTemporaryFile zipFile;
             if (!zipFile.open())
             {
-                kDebug( 51000 ) << "DNGWriter: Cannot open temporary file to write Zip Raw file. Aborted..." << endl;
+                kDebug(51000) << "DNGWriter: Cannot open temporary file to write Zip Raw file. Aborted..." << endl;
                 return -1;
             }
             KZip zipArchive(zipFile.fileName());
@@ -666,7 +666,7 @@ int DNGWriter::convert()
             zipRawFileData.resize(zipFileInfo.size());
             QDataStream dataStream(&zipFile);
             dataStream.readRawData(zipRawFileData.data(), zipRawFileData.size());
-            kDebug( 51000 ) << "DNGWriter: Zipped RAW file size " << zipRawFileData.size() << " bytes" << endl;
+            kDebug(51000) << "DNGWriter: Zipped RAW file size " << zipRawFileData.size() << " bytes" << endl;
 
             // Pass byte array to DNG sdk and compute MD5 fingerprint.
 
@@ -690,7 +690,7 @@ int DNGWriter::convert()
 
         // -----------------------------------------------------------------------------------------
 
-        kDebug( 51000 ) << "DNGWriter: Build DNG Negative" << endl;
+        kDebug(51000) << "DNGWriter: Build DNG Negative" << endl;
 
         // Assign Raw image data.
         negative->SetStage1Image(image);
@@ -715,7 +715,7 @@ int DNGWriter::convert()
 
         if (d->previewMode != DNGWriter::NONE)
         {
-            kDebug( 51000 ) << "DNGWriter: DNG preview image creation" << endl;
+            kDebug(51000) << "DNGWriter: DNG preview image creation" << endl;
 
             // Construct a preview image as TIFF format.
             AutoPtr<dng_image> tiffImage;
@@ -740,20 +740,20 @@ int DNGWriter::convert()
             QImage pre_image;
             if (!pre_image.loadFromData((uchar*)&tiff_mem_buffer.front(), tiff_mem_buffer.size(), "TIFF"))
             {
-                kDebug( 51000 ) << "DNGWriter: Cannot load TIFF preview data in memory. Aborted..." << endl;
+                kDebug(51000) << "DNGWriter: Cannot load TIFF preview data in memory. Aborted..." << endl;
                 return -1;
             }
 
             QTemporaryFile previewFile;
             if (!previewFile.open())
             {
-                kDebug( 51000 ) << "DNGWriter: Cannot open temporary file to write JPEG preview. Aborted..." << endl;
+                kDebug(51000) << "DNGWriter: Cannot open temporary file to write JPEG preview. Aborted..." << endl;
                 return -1;
             }
 
             if (!pre_image.save(previewFile.fileName(), "JPEG", 90))
             {
-                kDebug( 51000 ) << "DNGWriter: Cannot save file to write JPEG preview. Aborted..." << endl;
+                kDebug(51000) << "DNGWriter: Cannot save file to write JPEG preview. Aborted..." << endl;
                 return -1;
             }
 
@@ -780,7 +780,7 @@ int DNGWriter::convert()
 
         // -----------------------------------------------------------------------------------------
 
-        kDebug( 51000 ) << "DNGWriter: DNG thumbnail creation" << endl;
+        kDebug(51000) << "DNGWriter: DNG thumbnail creation" << endl;
 
         dng_image_preview thumbnail;
         dng_render thumbnail_render(host, *negative);
@@ -793,19 +793,19 @@ int DNGWriter::convert()
 
         // -----------------------------------------------------------------------------------------
 
-        kDebug( 51000 ) << "DNGWriter: Creating DNG file " << outputInfo.fileName() << endl;
+        kDebug(51000) << "DNGWriter: Creating DNG file " << outputInfo.fileName() << endl;
 
         dng_image_writer writer;
         dng_file_stream filestream(QFile::encodeName(dngFilePath), true);
 
-        writer.WriteDNG(host, filestream, *negative.Get(), thumbnail, 
+        writer.WriteDNG(host, filestream, *negative.Get(), thumbnail,
                         d->jpegLossLessCompression ? ccJPEG : ccUncompressed,
                         &previewList);
 
         // -----------------------------------------------------------------------------------------
         // Metadata transfert using Exiv2. Used to restore Makernote offset.
 
-        kDebug( 51000 ) << "DNGWriter: Backup meta-data using Exiv2" << endl;
+        kDebug(51000) << "DNGWriter: Backup meta-data using Exiv2" << endl;
         KExiv2 dngMeta(dngFilePath);
 
         if (meta.load(inputFile()))
@@ -820,17 +820,17 @@ int DNGWriter::convert()
     catch (const dng_exception &exception)
     {
         int ret = exception.ErrorCode();
-        kDebug( 51000 ) << "DNGWriter: DNG SDK exception code (" << ret << ")" << endl;
+        kDebug(51000) << "DNGWriter: DNG SDK exception code (" << ret << ")" << endl;
         return ret;
     }
 
     catch (...)
     {
-        kDebug( 51000 ) << "DNGWriter: DNG SDK exception code unknow" << endl;
+        kDebug(51000) << "DNGWriter: DNG SDK exception code unknow" << endl;
         return dng_error_unknown;
     }
 
-    kDebug( 51000 ) << "DNGWriter: DNG conversion complete..." << endl;
+    kDebug(51000) << "DNGWriter: DNG conversion complete..." << endl;
 
     return dng_error_none;
 }
