@@ -23,7 +23,7 @@
 #include "batchdialog.h"
 #include "batchdialog.moc"
 
-// Qt includes.
+// Qt includes
 
 #include <QCloseEvent>
 #include <QFile>
@@ -36,7 +36,7 @@
 #include <QTimer>
 #include <QTreeWidgetItemIterator>
 
-// KDE includes.
+// KDE includes
 
 #include <kapplication.h>
 #include <kconfig.h>
@@ -52,12 +52,12 @@
 #include <kstandarddirs.h>
 #include <ktoolinvocation.h>
 
-// LibKIPI includes.
+// LibKIPI includes
 
 #include <libkipi/imageinfo.h>
 #include <libkipi/interface.h>
 
-// Local includes.
+// Local includes
 
 #include "aboutdata.h"
 #include "actions.h"
@@ -324,7 +324,7 @@ void BatchDialog::slotStartStop()
 
         if (d->fileList.empty())
         {
-            KMessageBox::error(this, i18n("There is no Raw file to process in the list!"));
+            KMessageBox::error(this, i18n("The list does not contain any Raw files to process."));
             busy(false);
             slotAborted();
             return;
@@ -463,17 +463,17 @@ void BatchDialog::busy(bool busy)
     {
         setButtonIcon(Apply, KIcon("process-stop"));
         setButtonText(Apply, i18n("&Abort"));
-        setButtonToolTip(Apply, i18n("Abort the current Raw files conversion"));
+        setButtonToolTip(Apply, i18n("Abort the conversion of Raw files."));
     }
     else
     {
         setButtonIcon(Apply, KIcon("system-run"));
         setButtonText(Apply, i18n("Con&vert"));
-        setButtonToolTip(Apply, i18n("Start converting the Raw images from current settings"));
+        setButtonToolTip(Apply, i18n("Start converting the Raw images using the current settings."));
     }
 
     d->settingsBox->setEnabled(!d->busy);
-    d->listView->setEnabled(!d->busy);
+    d->listView->viewport()->setEnabled(!d->busy);
 
     d->busy ? d->page->setCursor(Qt::WaitCursor) : d->page->unsetCursor();
 }
