@@ -169,7 +169,7 @@ bool SimpleViewer::configure()
         {
             int ret = KMessageBox::warningYesNoCancel(kapp->activeWindow(),
                                                       i18n("Target folder %1 already exists.\n"
-                                                           "Do you want to overwrite it (all data in this folder will be lost)",
+                                                           "Do you want to overwrite it?  All data in this folder will be lost.",
                                                            d->configDlg->settings().exportUrl.path()));
 
             switch(ret)
@@ -177,8 +177,8 @@ bool SimpleViewer::configure()
                 case KMessageBox::Yes:
                     if(!KIO::NetAccess::del(d->configDlg->settings().exportUrl, kapp->activeWindow()))
                     {
-                        KMessageBox::error(kapp->activeWindow(), i18n("Could not delete %1\n"
-                                           "Please choose another export folder",
+                        KMessageBox::error(kapp->activeWindow(), i18n("Could not delete %1.\n"
+                                           "Please choose another export folder.",
                                            d->configDlg->settings().exportUrl.path()));
                         configured = false;
                     }
@@ -281,7 +281,7 @@ void SimpleViewer::slotProcess()
     {
         int ret = KMessageBox::warningYesNo(kapp->activeWindow(),
                                             i18n("Export was canceled.\n"
-                                                 "Do you want to delete the yet created files in %1 ?",
+                                                 "Do you want to delete files in %1 that have already been created?",
                                                  d->configDlg->settings().exportUrl.path()));
         if(ret == KMessageBox::Yes)
         {
@@ -560,7 +560,7 @@ bool SimpleViewer::createIndex()
     if(indexTemplateName.isEmpty())
     {
         //TODO: errormsg
-        kDebug( 51000 ) << "No indexTemplateName" << endl;
+        kDebug(51000) << "No indexTemplateName" << endl;
         return false;
     }
 
@@ -664,7 +664,7 @@ bool SimpleViewer::installSimpleViewer()
         }
         else
         {
-            kDebug( 51000 ) << "Archive extraction failed\n";
+            kDebug(51000) << "Archive extraction failed\n";
         }
     }
 
@@ -687,7 +687,7 @@ bool SimpleViewer::openArchive(KZip &zip)
 {
     if(!zip.open(QIODevice::ReadOnly))
     {
-        kDebug( 51000 ) << "Open archive failed\n";
+        kDebug(51000) << "Open archive failed\n";
         return false;
     }
     return true;
@@ -699,8 +699,8 @@ bool SimpleViewer::extractArchive(KZip &zip)
     QStringList names = zip.directory()->entries();
     if(names.count() != 1)
     {
-        kDebug( 51000 ) << "Wrong SimpleViewer Version or corrupted archive" << endl;
-        kDebug( 51000 ) << "Content of the archive root folder" << names << endl;
+        kDebug(51000) << "Wrong SimpleViewer Version or corrupted archive" << endl;
+        kDebug(51000) << "Content of the archive root folder" << names << endl;
         return false;
     }
 
@@ -708,7 +708,7 @@ bool SimpleViewer::extractArchive(KZip &zip)
     const KArchiveEntry *root = zip.directory()->entry(names[0]);
     if(!root || !root->isDirectory())
     {
-        kDebug( 51000 ) << "could not open " << names[0] << " of zipname" << endl;
+        kDebug(51000) << "could not open " << names[0] << " of zipname" << endl;
         return false;
     }
 
@@ -722,7 +722,7 @@ bool SimpleViewer::extractArchive(KZip &zip)
         if(!extractFile(entry))
         {
             //TODO error msg
-            kDebug( 51000 ) << "could not open " << *it << " of zipname" << endl;
+            kDebug(51000) << "could not open " << *it << " of zipname" << endl;
             return false;
         }
     }
