@@ -217,7 +217,7 @@ FlickrWindow::FlickrWindow(KIPI::Interface* interface, const QString &tmpFolder,
     m_talker->m_authProgressDlg = m_authProgressDlg;
     m_widget->setEnabled(false);
 
-    kDebug( 51000 ) << "Calling auth methods" << endl;
+    kDebug(51000) << "Calling auth methods" << endl;
 
     if(m_token.length()< 1)
         m_talker->getFrob();
@@ -319,7 +319,7 @@ void FlickrWindow::slotTokenObtained(const QString& token)
     m_token    = token;
     m_username = m_talker->getUserName();
     m_userId   = m_talker->getUserId();
-    kDebug( 51000 ) << "SlotTokenObtained invoked setting user Display name to " << m_username << endl;
+    kDebug(51000) << "SlotTokenObtained invoked setting user Display name to " << m_username << endl;
     m_userNameDisplayLabel->setText(QString("<b>%1</b>").arg(m_username));
     m_talker->listPhotoSets();
 }
@@ -348,7 +348,7 @@ void FlickrWindow::slotError(const QString& msg)
 
 void FlickrWindow::slotUserChangeRequest()
 {
-    kDebug( 51000 ) << "Slot Change User Request " << endl;
+    kDebug(51000) << "Slot Change User Request " << endl;
     m_talker->getFrob();
 //  m_addPhotoButton->setEnabled(m_selectImagesButton->isChecked());
 }
@@ -366,7 +366,7 @@ void FlickrWindow::slotCreateNewPhotoSet()
    }
    else
    {
-     kDebug() << "New Photoset creation aborted " << endl;
+     kDebug(51000) << "New Photoset creation aborted " << endl;
    }
 }
 
@@ -394,13 +394,15 @@ void FlickrWindow::slotOpenPhoto( const KUrl& url )
 
 void FlickrWindow::slotListPhotoSetsSucceeded()
 {
-    kDebug( 51000 ) << "SlotListPhotoSetsResponse invoked" << endl;
+    kDebug(51000) << "SlotListPhotoSetsResponse invoked" << endl;
     if (m_talker && m_talker->m_photoSetsList)
     {
         QLinkedList <FPhotoSet> *list = m_talker->m_photoSetsList;
         m_albumsListComboBox->clear();
+        m_albumsListComboBox->insertItem(0, i18n("<Photostream Only>"));
+        m_albumsListComboBox->insertSeparator(1);
         QLinkedList<FPhotoSet>::iterator it = list->begin();
-	    int index = 0;
+        int index = 2;
         while(it != list->end())
         {
             FPhotoSet photoSet=*it;
@@ -417,7 +419,7 @@ void FlickrWindow::slotListPhotoSetsSucceeded()
 */
 void FlickrWindow::slotUser1()
 {
-    kDebug( 51000 ) << "SlotUploadImages invoked" << endl;
+    kDebug(51000) << "SlotUploadImages invoked" << endl;
 
     m_widget->m_tab->setCurrentIndex(FlickrWidget::FILELIST);
     KUrl::List urls = m_imglst->imageUrls();
@@ -432,7 +434,7 @@ void FlickrWindow::slotUser1()
     for (KUrl::List::iterator it = urls.begin(); it != urls.end(); ++it)
     {
         KIPI::ImageInfo info = m_interface->info(*it);
-        kDebug( 51000 ) << "Adding images to the list" << endl;
+        kDebug(51000) << "Adding images to the list" << endl;
         FPhotoInfo temp;
 
         temp.title                 = info.title();
@@ -479,7 +481,7 @@ void FlickrWindow::slotUser1()
 
         while(itTags != allTags.end())
         {
-            kDebug( 51000 ) << "Tags list: " << (*itTags) << endl;
+            kDebug(51000) << "Tags list: " << (*itTags) << endl;
             ++itTags;
         }
 
@@ -491,7 +493,7 @@ void FlickrWindow::slotUser1()
     m_uploadCount = 0;
     m_progressDlg->reset();
     slotAddPhotoNext();
-    kDebug( 51000 ) << "SlotUploadImages done" << endl;
+    kDebug(51000) << "SlotUploadImages done" << endl;
 }
 
 void FlickrWindow::slotAddPhotoNext()
@@ -551,7 +553,7 @@ void FlickrWindow::slotAddPhotoSucceeded()
 
 void FlickrWindow::slotListPhotoSetsFailed(const QString& msg) {
     KMessageBox::error(this,
-                 i18n("Failed to Fetch Photosets information from %1. %2\n", m_serviceName, msg));
+                 i18n("Failed to Fetch Photoset information from %1. %2\n", m_serviceName, msg));
 }
 void FlickrWindow::slotAddPhotoFailed(const QString& msg)
 {
