@@ -23,13 +23,13 @@
 #include "gpstracklisteditdialog.h"
 #include "gpstracklisteditdialog.moc"
 
-// Qt includes.
+// Qt includes
 
 #include <QTimer>
 #include <QTreeWidgetItemIterator>
 #include <QVBoxLayout>
 
-// KDE includes.
+// KDE includes
 
 #include <kapplication.h>
 #include <kconfig.h>
@@ -42,13 +42,14 @@
 #include <kpushbutton.h>
 #include <ktoolinvocation.h>
 
-// Local includes.
+// Local includes
 
 #include "gpstracklistviewitem.h"
 #include "gpstracklistwidget.h"
 #include "imageslist.h"
 #include "kpaboutdata.h"
 #include "pluginsversion.h"
+#include "gpslistviewcontextmenu.h"
 
 namespace KIPIGPSSyncPlugin
 {
@@ -106,6 +107,9 @@ GPSTrackListEditDialog::GPSTrackListEditDialog(KIPI::Interface* interface, QWidg
     d->imagesList->listView()->setColumn(KIPIPlugins::ImagesListView::User6,
                                        i18n("Changed"), true);
 
+    // add the context menu provider to the imagesList:
+    new GPSListViewContextMenu(d->imagesList);
+
     d->worldMap       = new GPSTrackListWidget(page);
     d->worldMap->show();
 
@@ -122,7 +126,7 @@ GPSTrackListEditDialog::GPSTrackListEditDialog(KIPI::Interface* interface, QWidg
     d->about = new KIPIPlugins::KPAboutData(ki18n("GPS Sync"),
                    0,
                    KAboutData::License_GPL,
-                   ki18n("A Plugin to edit GPS track list"),
+                   ki18n("A plugin to edit GPS track lists."),
                    ki18n("(c) 2008-2009, Gilles Caulier"));
 
     d->about->addAuthor(ki18n("Gilles Caulier"),
