@@ -190,8 +190,14 @@ BatchDialog::BatchDialog(KIPI::Interface* iface)
                                                               DcrawSettingsWidget::BLACKWHITEPOINTS);
     d->saveSettingsBox     = new SaveSettingsWidget(d->page);
 
+#if KDCRAW_VERSION <= 0x000500
     d->decodingSettingsBox->addItem(d->saveSettingsBox, i18n("Save settings"));
     d->decodingSettingsBox->updateMinimumWidth();
+#else
+    d->decodingSettingsBox->insertItem(DcrawSettingsWidget::COLORMANAGEMENT+1, d->saveSettingsBox,
+                                       SmallIcon("document-save"), i18n("Save settings"),
+                                       QString("savesettings"), false);
+#endif
 
     d->progressBar = new QProgressBar(d->page);
     d->progressBar->setMaximumHeight( fontMetrics().height()+2 );
@@ -200,10 +206,12 @@ BatchDialog::BatchDialog(KIPI::Interface* iface)
     mainLayout->addWidget(d->listView,            0, 0, 3, 1);
     mainLayout->addWidget(d->decodingSettingsBox, 0, 1, 1, 1);
     mainLayout->addWidget(d->progressBar,         1, 1, 1, 1);
-    mainLayout->setColumnStretch(0, 10);
-    mainLayout->setRowStretch(2, 10);
     mainLayout->setMargin(0);
     mainLayout->setSpacing(spacingHint());
+    mainLayout->setColumnStretch(0, 10);
+#if KDCRAW_VERSION <= 0x000500
+    mainLayout->setRowStretch(2, 10);
+#endif
 
     // ---------------------------------------------------------------
     // About data and help button.
@@ -373,6 +381,9 @@ void BatchDialog::readSettings()
     d->saveSettingsBox->slotPopulateImageFormat(d->decodingSettingsBox->sixteenBits());
 
     KConfigGroup group2 = config.group(QString("Batch Raw Converter Dialog"));
+#if KDCRAW_VERSION > 0x000500
+    d->decodingSettingsBox->readSettings(group2);
+#endif
     restoreDialogSize(group2);
 }
 
@@ -408,6 +419,9 @@ void BatchDialog::saveSettings()
     group.writeEntry("Conflict", (int)d->saveSettingsBox->conflictRule());
 
     KConfigGroup group2 = config.group(QString("Batch Raw Converter Dialog"));
+#if KDCRAW_VERSION > 0x000500
+    d->decodingSettingsBox->writeSettings(group2);
+#endif
     saveDialogSize(group2);
     config.sync();
 }
@@ -663,7 +677,7 @@ void BatchDialog::busy(bool busy)
 
     d->decodingSettingsBox->setEnabled(!d->busy);
     d->saveSettingsBox->setEnabled(!d->busy);
-    d->listView->setEnabled(!d->busy);
+    d->listView->viewport()->setEnabled(!d->busy);
 
     d->busy ? d->page->setCursor(Qt::WaitCursor) : d->page->unsetCursor();
 }
