@@ -24,7 +24,7 @@
 #ifndef UNPROCESSEDSETTINGSBOX_H
 #define UNPROCESSEDSETTINGSBOX_H
 
-// Qt includes.
+// Qt includes
 
 #include <QGroupBox>
 
@@ -52,7 +52,7 @@ public:
     int handleMode() const;
     void setHandleMode(int mode);
 
-signals:
+Q_SIGNALS:
 
     void settingsChanged();
 
